/**
 * $Id: sc_stack.c,v 1.4 2004/09/04 07:08:01 jklein Exp $
 * $Author: jklein $
 * $Log: sc_stack.c,v $
 * Revision 1.4  2004/09/04 07:08:01  jklein
 * fixed "const spointer" to "sconstpointer".
 *
 * Revision 1.3  2004/06/21 16:44:17  jklein
 * Added iterator.
 *
 */


#include <scale/stack.h>


spointer
s_stack_peek(sstack_t *stack)
{
	return stack->array[stack->count-1];
}


spointer
s_stack_pop(sstack_t *stack)
{
	spointer contents;
	contents = s_vector_remove(stack, s_vector_size(stack) - 1);
	return contents;
}

